pygeodesy.rhumb.ekx

Package pygeodesy :: Package rhumb :: Module ekx |
[frames] | no frames]

# Module ekx

A pure Python version of Karney's elliptic functions, Krüger series expansion, C++ classes Rhumb and and RhumbLine from GeographicLib version 2.0, kept for backward compatibility.

Class RhumbLine has been enhanced with methods `Intersecant2`, `Intersection` and `PlumbTo` to iteratively find the intersection of a rhumb line and a circle or an other rhumb line, respectively a perpendicular geodesic or other rhumb line.

For more details, see the C++ GeographicLib documentation, especially the Class List, the background information on Rhumb lines, the utily RhumbSolve and Online rhumb line calculations.

Copyright (C) Charles Karney (2014-2024) and licensed under the MIT/X11 License. For more information, see the GeographicLib documentation.

Version: 25.08.31

Classes
| Caps Enum-style masks to be bit-`or`'ed to specify `geodesic`, `rhumb` or `-lines` capabilities (`caps`) and method results (`outmask`).
| Rhumb Class to solve the direct and inverse rhumb problems, based on elliptic functions or Krüger series expansion
| RhumbLine Compute one or several points on a single rhumb line.

Variables
| __all__ = `_ALL_LAZY.rhumb_ekx`